@@ -2,6 +2,12 @@ predict.fregre.fd<-function(object,new.fdataobj=NULL,...){
 if (is.null(object)) stop("No fregre.fd object entered")
 if (is.null(new.fdataobj)) stop("No newx entered")
 if (!is.fdata(new.fdataobj)) new.fdataobj=fdata(new.fdataobj,object$fdataobj[["argvals"]],object$fdataobj[["rangeval"]],object$fdataobj[["names"]])
+y=object$y
+isfdata<-is.fdata(y)
+if (!isfdata) {
+   if (is.vector(y)) y.mat<-matrix(y,ncol=1)
+   }
+else y.mat<-y$data
 gg<-1:nrow(new.fdataobj)
 nas<-apply(new.fdataobj$data,1,count.na)
 if (any(nas)) {
@@ -19,7 +25,7 @@ nn <- nrow(new.fdataobj)
  a1<-object$coefficients[1]*rep(1,len=nrow(newx))
  object$beta.est$data<-matrix(object$beta.est$data,nrow=1)
 # b2<-new.fdataobj$data%*%t(object$beta.est$data)
- b1<-inprod.fdata(fdata.cen(new.fdataobj,object$pc$mean)[[1]],object$beta.est)#/(ncol(newx)-1)
+ b1<-inprod.fdata(fdata.cen(new.fdataobj,object$fdata.comp$mean)[[1]],object$beta.est)#/(ncol(newx)-1)
  yp<- a1+b1
  }
  else {
@@ -27,7 +33,7 @@ nn <- nrow(new.fdataobj)
   a1<-object$coefficients[1]*rep(1,len=nrow(newx))
   object$beta.est$data<-matrix(object$beta.est$data,nrow=1)
 #  b2<-new.fdataobj$data%*%t(object$beta.est$data)
-  b1<-inprod.fdata(fdata.cen(new.fdataobj,object$pls.fdata$mean)[[1]],object$beta.est)#/(ncol(newx)-1)
+  b1<-inprod.fdata(fdata.cen(new.fdataobj,object$fdata.comp$mean)[[1]],object$beta.est)#/(ncol(newx)-1)
   yp<- a1+b1
  }
  else {
@@ -47,47 +53,33 @@ nn <- nrow(new.fdataobj)
  if (object$call[[1]]=="fregre.np" || object$call[[1]]=="fregre.np.cv"){
 # if (is.vector(newx))  newx <- t(as.matrix(newx))
  x=object$fdataobj
- y=object$y
  h=object$h.opt
  n = nrow(x)
  nn = nrow(newx)
  np <- ncol(x)
 # if (n != (length(y)))         stop("ERROR IN THE DATA DIMENSIONS")
  if (is.null(rownames(newx)))         rownames(newx) <- 1:nn
+ par.S<-object$par.S
  bs=as<-list()
- C<-object$call
- m<-object$m
  Ker=object$Ker
- imetric<-m[5]
- if (imetric==0) {
-      a1<-metric.lp
-      len.metricc<-length(formals(a1))
-      vv<-array(0,dim=c(len.metricc))      }
- else {
-   a1<-match.fun(C[[imetric]])
-   len.metricc<-length(formals(a1))
-   vv<-array(0,dim=c(len.metricc))   }
-   ii<-imetric+1
-if (C[ii]!='NULL()')     {
-    ind.m<-3
-    while (C[ii]!='NULL()'&& ind.m<=len.metricc) {
-    aa<-any(names(C)==names(formals(a1))[ind.m])
-    if (aa) {
-           vv[ind.m]<-which(names(C)==names(formals(a1)[ind.m]))
-           ii<-ii+1
-           as[[ind.m]]<-C[[vv[ind.m]]]           }
-     else {as[[ind.m]]<-formals(a1)[[ind.m]]}
-       ind.m<-ind.m+1
- } }
- as[[2]]<-new.fdataobj
- as[[1]]<-x
- mdist<-do.call(a1,as,...)
- kmdist=Ker(mdist/h)
- a=t(kmdist)%*%matrix(y,ncol=1)
- b=apply(kmdist,2,sum)
- yp=a/b
-#   yp=t(object$type.S(mdist,h,object$Ker,cv=FALSE))%*%matrix(y,ncol=1)
- }}
+ #   par.metric<-list()
+   par.metric<-attr(object$mdist,"par.metric")
+   par.metric[["fdata1"]]<-new.fdataobj
+   par.metric[["fdata2"]]<-x
+#   parm<-attr(object$mdist,"par.metric")
+#   lenpar<-length(parm)
+#names(par.metric[3:(2+lenpar)])<-names(attr(object$mdist,"par.metric"))
+  a1<-attr(object$mdist,"call")
+  a2<-attr(object$par.S,"call")
+  nmdist <- do.call(a1,par.metric)
+  par.S$tt<-nmdist
+  par.S$cv=FALSE
+  H<-do.call(a2,par.S)
+  yp=H%*%y.mat
+ if (isfdata) {
+    return(fdata(yp,y$argvals,y$rtt,y$names))
+    }
+ }     }
  }     }
 #rownames(yp)=rownames(newx)
 yp<-drop(yp)
@@ -95,3 +87,4 @@ names(yp)<-gg
 return(yp)
 }
 
+
